import { TextRenderConfig } from '@jupyterlab/csvviewer';
import { DataGrid, CellRenderer } from '@lumino/datagrid';
import { ISignal } from '@lumino/signaling';
import { ISearchMatch } from '@jupyterlab/documentsearch';
/**
 * Responsible for finding matches within the datagrid and handling datagrid UI changes
 *
 * Search service remembers the search state and the location of the last
 * match, for incremental searching.
 * Search service is also responsible of providing a cell renderer function
 * to set the background color of cells matching the search text.
 */
export declare class GridSearchService {
    constructor(grid: DataGrid);
    /**
     * A signal fired when the grid changes.
     */
    get changed(): ISignal<GridSearchService, void>;
    get row(): number;
    get column(): number;
    get matches(): ISearchMatch[];
    get currentMatch(): ISearchMatch;
    /**
     * Returns a cellrenderer config function to render each cell background.
     * If cell match, background is matchBackgroundColor, if it's the current
     * match, background is currentMatchBackgroundColor.
     */
    cellBackgroundColorRendererFunc(config: TextRenderConfig): CellRenderer.ConfigFunc<string>;
    /**
     * Clear the search.
     */
    clear(): void;
    /**
     * incrementally look for searchText.
     */
    find(query: RegExp, reverse?: boolean): ISearchMatch[] | boolean;
    get query(): RegExp | null;
    highlightNext(reverse: boolean): ISearchMatch | undefined;
    private _grid;
    private _query;
    private _matches;
    private _row;
    private _column;
    private _currentMatch;
    private _changed;
}
